"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def attach(
    hub, ctx, security_profile_name: str, security_profile_target_arn: str
) -> Dict:
    r"""
    **Autogenerated function**

    Associates a Device Defender security profile with a thing group or this account. Each thing group or account can have up to five security profiles associated with it.

    Args:
        security_profile_name(str): The security profile that is attached.
        security_profile_target_arn(str): The ARN of the target (thing group) to which the security profile is attached.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.security_profile.init.attach(
                ctx, security_profile_name=value, security_profile_target_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.security_profile.init.attach security_profile_name=value, security_profile_target_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="attach_security_profile",
        op_kwargs={
            "securityProfileName": security_profile_name,
            "securityProfileTargetArn": security_profile_target_arn,
        },
    )


async def create(
    hub,
    ctx,
    security_profile_name: str,
    security_profile_description: str = None,
    behaviors: List = None,
    alert_targets: Dict = None,
    additional_metrics_to_retain: List = None,
    additional_metrics_to_retain_v2: List = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a Device Defender security profile.

    Args:
        security_profile_name(str): The name you are giving to the security profile.
        security_profile_description(str, optional): A description of the security profile. Defaults to None.
        behaviors(List, optional): Specifies the behaviors that, when violated by a device (thing), cause an alert. Defaults to None.
        alert_targets(Dict, optional): Specifies the destinations to which alerts are sent. (Alerts are always sent to the console.) Alerts are generated when a device (thing) violates a behavior. Defaults to None.
        additional_metrics_to_retain(List, optional):  Please use CreateSecurityProfileRequest$additionalMetricsToRetainV2 instead.  A list of metrics whose data is retained (stored). By default, data is retained for any metric used in the profile's behaviors, but it is also retained for any metric specified here. Can be used with custom metrics; cannot be used with dimensions. Defaults to None.
        additional_metrics_to_retain_v2(List, optional): A list of metrics whose data is retained (stored). By default, data is retained for any metric used in the profile's behaviors, but it is also retained for any metric specified here. Can be used with custom metrics; cannot be used with dimensions. Defaults to None.
        tags(List, optional): Metadata that can be used to manage the security profile. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.security_profile.init.create(
                ctx, security_profile_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.security_profile.init.create security_profile_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="create_security_profile",
        op_kwargs={
            "securityProfileName": security_profile_name,
            "securityProfileDescription": security_profile_description,
            "behaviors": behaviors,
            "alertTargets": alert_targets,
            "additionalMetricsToRetain": additional_metrics_to_retain,
            "additionalMetricsToRetainV2": additional_metrics_to_retain_v2,
            "tags": tags,
        },
    )


async def delete(
    hub, ctx, security_profile_name: str, expected_version: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a Device Defender security profile.

    Args:
        security_profile_name(str): The name of the security profile to be deleted.
        expected_version(int, optional): The expected version of the security profile. A new version is generated whenever the security profile is updated. If you specify a value that is different from the actual version, a VersionConflictException is thrown. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.security_profile.init.delete(
                ctx, security_profile_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.security_profile.init.delete security_profile_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="delete_security_profile",
        op_kwargs={
            "securityProfileName": security_profile_name,
            "expectedVersion": expected_version,
        },
    )


async def describe(hub, ctx, security_profile_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about a Device Defender security profile.

    Args:
        security_profile_name(str): The name of the security profile whose information you want to get.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.security_profile.init.describe(
                ctx, security_profile_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.security_profile.init.describe security_profile_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="describe_security_profile",
        op_kwargs={"securityProfileName": security_profile_name},
    )


async def detach(
    hub, ctx, security_profile_name: str, security_profile_target_arn: str
) -> Dict:
    r"""
    **Autogenerated function**

    Disassociates a Device Defender security profile from a thing group or from this account.

    Args:
        security_profile_name(str): The security profile that is detached.
        security_profile_target_arn(str): The ARN of the thing group from which the security profile is detached.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.security_profile.init.detach(
                ctx, security_profile_name=value, security_profile_target_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.security_profile.init.detach security_profile_name=value, security_profile_target_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="detach_security_profile",
        op_kwargs={
            "securityProfileName": security_profile_name,
            "securityProfileTargetArn": security_profile_target_arn,
        },
    )


async def list_all(
    hub,
    ctx,
    next_token: str = None,
    max_results: int = None,
    dimension_name: str = None,
    metric_name: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the Device Defender security profiles you've created. You can filter security profiles by dimension or custom metric.   dimensionName and metricName cannot be used in the same request.

    Args:
        next_token(str, optional): The token for the next set of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return at one time. Defaults to None.
        dimension_name(str, optional): A filter to limit results to the security profiles that use the defined dimension. Cannot be used with metricName . Defaults to None.
        metric_name(str, optional):  The name of the custom metric. Cannot be used with dimensionName. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.security_profile.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.security_profile.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="list_security_profiles",
        op_kwargs={
            "nextToken": next_token,
            "maxResults": max_results,
            "dimensionName": dimension_name,
            "metricName": metric_name,
        },
    )


async def update(
    hub,
    ctx,
    security_profile_name: str,
    security_profile_description: str = None,
    behaviors: List = None,
    alert_targets: Dict = None,
    additional_metrics_to_retain: List = None,
    additional_metrics_to_retain_v2: List = None,
    delete_behaviors: bool = None,
    delete_alert_targets: bool = None,
    delete_additional_metrics_to_retain: bool = None,
    expected_version: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a Device Defender security profile.

    Args:
        security_profile_name(str): The name of the security profile you want to update.
        security_profile_description(str, optional): A description of the security profile. Defaults to None.
        behaviors(List, optional): Specifies the behaviors that, when violated by a device (thing), cause an alert. Defaults to None.
        alert_targets(Dict, optional): Where the alerts are sent. (Alerts are always sent to the console.). Defaults to None.
        additional_metrics_to_retain(List, optional):  Please use UpdateSecurityProfileRequest$additionalMetricsToRetainV2 instead.  A list of metrics whose data is retained (stored). By default, data is retained for any metric used in the profile's behaviors, but it is also retained for any metric specified here. Can be used with custom metrics; cannot be used with dimensions. Defaults to None.
        additional_metrics_to_retain_v2(List, optional): A list of metrics whose data is retained (stored). By default, data is retained for any metric used in the profile's behaviors, but it is also retained for any metric specified here. Can be used with custom metrics; cannot be used with dimensions. Defaults to None.
        delete_behaviors(bool, optional): If true, delete all behaviors defined for this security profile. If any behaviors are defined in the current invocation, an exception occurs. Defaults to None.
        delete_alert_targets(bool, optional): If true, delete all alertTargets defined for this security profile. If any alertTargets are defined in the current invocation, an exception occurs. Defaults to None.
        delete_additional_metrics_to_retain(bool, optional): If true, delete all additionalMetricsToRetain defined for this security profile. If any additionalMetricsToRetain are defined in the current invocation, an exception occurs. Defaults to None.
        expected_version(int, optional): The expected version of the security profile. A new version is generated whenever the security profile is updated. If you specify a value that is different from the actual version, a VersionConflictException is thrown. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.security_profile.init.update(
                ctx, security_profile_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.security_profile.init.update security_profile_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="update_security_profile",
        op_kwargs={
            "securityProfileName": security_profile_name,
            "securityProfileDescription": security_profile_description,
            "behaviors": behaviors,
            "alertTargets": alert_targets,
            "additionalMetricsToRetain": additional_metrics_to_retain,
            "additionalMetricsToRetainV2": additional_metrics_to_retain_v2,
            "deleteBehaviors": delete_behaviors,
            "deleteAlertTargets": delete_alert_targets,
            "deleteAdditionalMetricsToRetain": delete_additional_metrics_to_retain,
            "expectedVersion": expected_version,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def associate(
    hub, ctx, targets: List, job_id: str, comment: str = None, namespace_id: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Associates a group with a continuous job. The following criteria must be met:    The job must have been created with the targetSelection field set to "CONTINUOUS".   The job status must currently be "IN_PROGRESS".   The total number of targets associated with a job must not exceed 100.

    Args:
        targets(List): A list of thing group ARNs that define the targets of the job.
        job_id(str): The unique identifier you assigned to this job when it was created.
        comment(str, optional): An optional comment string describing why the job was associated with the targets. Defaults to None.
        namespace_id(str, optional): The namespace used to indicate that a job is a customer-managed job. When you specify a value for this parameter, AWS IoT Core sends jobs notifications to MQTT topics that contain the value in the following format.  $aws/things/THING_NAME/jobs/JOB_ID/notify-namespace-NAMESPACE_ID/   The namespaceId feature is in public preview. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.target.with_job.associate(ctx, targets=value, job_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.target.with_job.associate targets=value, job_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="associate_targets_with_job",
        op_kwargs={
            "targets": targets,
            "jobId": job_id,
            "comment": comment,
            "namespaceId": namespace_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def put_multiple(
    hub, ctx, email_identity: str, signing_enabled: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Used to enable or disable DKIM authentication for an email identity.

    Args:
        email_identity(str): The email identity that you want to change the DKIM settings for.
        signing_enabled(bool, optional): Sets the DKIM signing configuration for the identity. When you set this value true, then the messages that Amazon Pinpoint sends from the identity are DKIM-signed. When you set this value to false, then the messages that Amazon Pinpoint sends from the identity aren't DKIM-signed. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.pinpoint_email.email.identity.dkim_attribute.put_multiple(
                ctx, email_identity=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.pinpoint_email.email.identity.dkim_attribute.put_multiple email_identity=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="pinpoint-email",
        operation="put_email_identity_dkim_attributes",
        op_kwargs={"EmailIdentity": email_identity, "SigningEnabled": signing_enabled},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def request(
    hub, ctx, spot_fleet_request_config: Dict, dry_run: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a Spot Fleet request. The Spot Fleet request specifies the total target capacity and the On-Demand target capacity. Amazon EC2 calculates the difference between the total capacity and On-Demand capacity, and launches the difference as Spot capacity. You can submit a single request that includes multiple launch specifications that vary by instance type, AMI, Availability Zone, or subnet. By default, the Spot Fleet requests Spot Instances in the Spot Instance pool where the price per unit is the lowest. Each launch specification can include its own instance weighting that reflects the value of the instance type to your application workload. Alternatively, you can specify that the Spot Fleet distribute the target capacity across the Spot pools included in its launch specifications. By ensuring that the Spot Instances in your Spot Fleet are in different Spot pools, you can improve the availability of your fleet. You can specify tags for the Spot Fleet request and instances launched by the fleet. You cannot tag other resource types in a Spot Fleet request because only the spot-fleet-request and instance resource types are supported. For more information, see Spot Fleet requests in the Amazon EC2 User Guide for Linux Instances.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        spot_fleet_request_config(Dict): The configuration for the Spot Fleet request.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.spot.fleet.init.request(
                ctx, spot_fleet_request_config=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.spot.fleet.init.request spot_fleet_request_config=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="request_spot_fleet",
        op_kwargs={
            "DryRun": dry_run,
            "SpotFleetRequestConfig": spot_fleet_request_config,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    project_name: str,
    dataset_type: str,
    dataset_source: Dict = None,
    client_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new dataset in an Amazon Lookout for Vision project. CreateDataset can create a training or a test dataset from a valid dataset source (DatasetSource). If you want a single dataset project, specify train for the value of DatasetType. To have a project with separate training and test datasets, call CreateDataset twice. On the first call, specify train for the value of DatasetType. On the second call, specify test for the value of DatasetType.  This operation requires permissions to perform the lookoutvision:CreateDataset operation.

    Args:
        project_name(str): The name of the project in which you want to create a dataset.
        dataset_type(str): The type of the dataset. Specify train for a training dataset. Specify test for a test dataset.
        dataset_source(Dict, optional): The location of the manifest file that Amazon Lookout for Vision uses to create the dataset. If you don't specify DatasetSource, an empty dataset is created and the operation synchronously returns. Later, you can add JSON Lines by calling UpdateDatasetEntries.  If you specify a value for DataSource, the manifest at the S3 location is validated and used to create the dataset. The call to CreateDataset is asynchronous and might take a while to complete. To find out the current status, Check the value of Status returned in a call to DescribeDataset. Defaults to None.
        client_token(str, optional): ClientToken is an idempotency token that ensures a call to CreateDataset completes only once. You choose the value to pass. For example, An issue, such as an network outage, might prevent you from getting a response from CreateDataset. In this case, safely retry your call to CreateDataset by using the same ClientToken parameter value. An error occurs if the other input parameters are not the same as in the first request. Using a different value for ClientToken is considered a new call to CreateDataset. An idempotency token is active for 8 hours. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lookoutvision.dataset.init.create(
                ctx, project_name=value, dataset_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lookoutvision.dataset.init.create project_name=value, dataset_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lookoutvision",
        operation="create_dataset",
        op_kwargs={
            "ProjectName": project_name,
            "DatasetType": dataset_type,
            "DatasetSource": dataset_source,
            "ClientToken": client_token,
        },
    )


async def delete(
    hub, ctx, project_name: str, dataset_type: str, client_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an existing Amazon Lookout for Vision dataset.  If your the project has a single dataset, you must create a new dataset before you can create a model. If you project has a training dataset and a test dataset consider the following.    If you delete the test dataset, your project reverts to a single dataset project. If you then train the model, Amazon Lookout for Vision internally splits the remaining dataset into a training and test dataset.   If you delete the training dataset, you must create a training dataset before you can create a model.   This operation requires permissions to perform the lookoutvision:DeleteDataset operation.

    Args:
        project_name(str): The name of the project that contains the dataset that you want to delete.
        dataset_type(str): The type of the dataset to delete. Specify train to delete the training dataset. Specify test to delete the test dataset. To delete the dataset in a single dataset project, specify train.
        client_token(str, optional): ClientToken is an idempotency token that ensures a call to DeleteDataset completes only once. You choose the value to pass. For example, An issue, such as an network outage, might prevent you from getting a response from DeleteDataset. In this case, safely retry your call to DeleteDataset by using the same ClientToken parameter value. An error occurs if the other input parameters are not the same as in the first request. Using a different value for ClientToken is considered a new call to DeleteDataset. An idempotency token is active for 8 hours. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lookoutvision.dataset.init.delete(
                ctx, project_name=value, dataset_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lookoutvision.dataset.init.delete project_name=value, dataset_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lookoutvision",
        operation="delete_dataset",
        op_kwargs={
            "ProjectName": project_name,
            "DatasetType": dataset_type,
            "ClientToken": client_token,
        },
    )


async def describe(hub, ctx, project_name: str, dataset_type: str) -> Dict:
    r"""
    **Autogenerated function**

    Describe an Amazon Lookout for Vision dataset. This operation requires permissions to perform the lookoutvision:DescribeDataset operation.

    Args:
        project_name(str): The name of the project that contains the dataset that you want to describe.
        dataset_type(str): The type of the dataset to describe. Specify train to describe the training dataset. Specify test to describe the test dataset. If you have a single dataset project, specify train .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lookoutvision.dataset.init.describe(
                ctx, project_name=value, dataset_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lookoutvision.dataset.init.describe project_name=value, dataset_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lookoutvision",
        operation="describe_dataset",
        op_kwargs={"ProjectName": project_name, "DatasetType": dataset_type},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def update(
    hub, ctx, stream_name: str, target_shard_count: int, scaling_type: str
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the shard count of the specified stream to the specified number of shards. Updating the shard count is an asynchronous operation. Upon receiving the request, Kinesis Data Streams returns immediately and sets the status of the stream to UPDATING. After the update is complete, Kinesis Data Streams sets the status of the stream back to ACTIVE. Depending on the size of the stream, the scaling action could take a few minutes to complete. You can continue to read and write data to your stream while its status is UPDATING. To update the shard count, Kinesis Data Streams performs splits or merges on individual shards. This can cause short-lived shards to be created, in addition to the final shards. These short-lived shards count towards your total shard limit for your account in the Region. When using this operation, we recommend that you specify a target shard count that is a multiple of 25% (25%, 50%, 75%, 100%). You can specify any target value within your shard limit. However, if you specify a target that isn't a multiple of 25%, the scaling action might take longer to complete.  This operation has the following default limits. By default, you cannot do the following:   Scale more than ten times per rolling 24-hour period per stream   Scale up to more than double your current shard count for a stream   Scale down below half your current shard count for a stream   Scale up to more than 500 shards in a stream   Scale a stream with more than 500 shards down unless the result is less than 500 shards   Scale up to more than the shard limit for your account   For the default limits for an AWS account, see Streams Limits in the Amazon Kinesis Data Streams Developer Guide. To request an increase in the call rate limit, the shard limit for this API, or your overall shard limit, use the limits form.

    Args:
        stream_name(str): The name of the stream.
        target_shard_count(int): The new number of shards. This value has the following default limits. By default, you cannot do the following:    Set this value to more than double your current shard count for a stream.   Set this value below half your current shard count for a stream.   Set this value to more than 500 shards in a stream (the default limit for shard count per stream is 500 per account per region), unless you request a limit increase.   Scale a stream with more than 500 shards down unless you set this value to less than 500 shards.  .
        scaling_type(str): The scaling type. Uniform scaling creates shards of equal size.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesis.shard.count.update(
                ctx, stream_name=value, target_shard_count=value, scaling_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesis.shard.count.update stream_name=value, target_shard_count=value, scaling_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesis",
        operation="update_shard_count",
        op_kwargs={
            "StreamName": stream_name,
            "TargetShardCount": target_shard_count,
            "ScalingType": scaling_type,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def clone(
    hub, ctx, app_id: str, backend_environment_name: str, target_environment_name: str
) -> Dict:
    r"""
    **Autogenerated function**

    This operation clones an existing backend.

    Args:
        app_id(str): The app ID.
        backend_environment_name(str): The name of the backend environment.
        target_environment_name(str): The name of the destination backend environment to be created.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.amplifybackend.backend.init.clone(
                ctx, app_id=value, backend_environment_name=value, target_environment_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.amplifybackend.backend.init.clone app_id=value, backend_environment_name=value, target_environment_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="amplifybackend",
        operation="clone_backend",
        op_kwargs={
            "AppId": app_id,
            "BackendEnvironmentName": backend_environment_name,
            "TargetEnvironmentName": target_environment_name,
        },
    )


async def create(
    hub,
    ctx,
    app_id: str,
    app_name: str,
    backend_environment_name: str,
    resource_config: Dict = None,
    resource_name: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    This operation creates a backend for an Amplify app. Backends are automatically created at the time of app creation.

    Args:
        app_id(str): The app ID.
        app_name(str): The name of the app.
        backend_environment_name(str): The name of the backend environment.
        resource_config(Dict, optional): The resource configuration for the create backend request. Defaults to None.
        resource_name(str, optional): The name of the resource. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.amplifybackend.backend.init.create(
                ctx, app_id=value, app_name=value, backend_environment_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.amplifybackend.backend.init.create app_id=value, app_name=value, backend_environment_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="amplifybackend",
        operation="create_backend",
        op_kwargs={
            "AppId": app_id,
            "AppName": app_name,
            "BackendEnvironmentName": backend_environment_name,
            "ResourceConfig": resource_config,
            "ResourceName": resource_name,
        },
    )


async def delete(hub, ctx, app_id: str, backend_environment_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Removes an existing environment from your Amplify project.

    Args:
        app_id(str): The app ID.
        backend_environment_name(str): The name of the backend environment.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.amplifybackend.backend.init.delete(
                ctx, app_id=value, backend_environment_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.amplifybackend.backend.init.delete app_id=value, backend_environment_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="amplifybackend",
        operation="delete_backend",
        op_kwargs={"AppId": app_id, "BackendEnvironmentName": backend_environment_name},
    )


async def get(hub, ctx, app_id: str, backend_environment_name: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Provides project-level details for your Amplify UI project.

    Args:
        app_id(str): The app ID.
        backend_environment_name(str, optional): The name of the backend environment. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.amplifybackend.backend.init.get(ctx, app_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.amplifybackend.backend.init.get app_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="amplifybackend",
        operation="get_backend",
        op_kwargs={"AppId": app_id, "BackendEnvironmentName": backend_environment_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    ml_model_id: str,
    ml_model_type: str,
    training_data_source_id: str,
    ml_model_name: str = None,
    parameters: Dict = None,
    recipe: str = None,
    recipe_uri: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new MLModel using the DataSource and the recipe as information sources.  An MLModel is nearly immutable. Users can update only the MLModelName and the ScoreThreshold in an MLModel without creating a new MLModel.   CreateMLModel is an asynchronous operation. In response to CreateMLModel, Amazon Machine Learning (Amazon ML) immediately returns and sets the MLModel status to PENDING. After the MLModel has been created and ready is for use, Amazon ML sets the status to COMPLETED.  You can use the GetMLModel operation to check the progress of the MLModel during the creation operation.  CreateMLModel requires a DataSource with computed statistics, which can be created by setting ComputeStatistics to true in CreateDataSourceFromRDS, CreateDataSourceFromS3, or CreateDataSourceFromRedshift operations.

    Args:
        ml_model_id(str): A user-supplied ID that uniquely identifies the MLModel.
        ml_model_name(str, optional): A user-supplied name or description of the MLModel. Defaults to None.
        ml_model_type(str): The category of supervised learning that this MLModel will address. Choose from the following types:   Choose REGRESSION if the MLModel will be used to predict a numeric value.   Choose BINARY if the MLModel result has two possible values.   Choose MULTICLASS if the MLModel result has a limited number of values.    For more information, see the Amazon Machine Learning Developer Guide.
        parameters(Dict, optional): A list of the training parameters in the MLModel. The list is implemented as a map of key-value pairs. The following is the current set of training parameters:    sgd.maxMLModelSizeInBytes - The maximum allowed size of the model. Depending on the input data, the size of the model might affect its performance.  The value is an integer that ranges from 100000 to 2147483648. The default value is 33554432.    sgd.maxPasses - The number of times that the training process traverses the observations to build the MLModel. The value is an integer that ranges from 1 to 10000. The default value is 10.    sgd.shuffleType - Whether Amazon ML shuffles the training data. Shuffling the data improves a model's ability to find the optimal solution for a variety of data types. The valid values are auto and none. The default value is none. We strongly recommend that you shuffle your data.    sgd.l1RegularizationAmount - The coefficient regularization L1 norm. It controls overfitting the data by penalizing large coefficients. This tends to drive coefficients to zero, resulting in a sparse feature set. If you use this parameter, start by specifying a small value, such as 1.0E-08. The value is a double that ranges from 0 to MAX_DOUBLE. The default is to not use L1 normalization. This parameter can't be used when L2 is specified. Use this parameter sparingly.    sgd.l2RegularizationAmount - The coefficient regularization L2 norm. It controls overfitting the data by penalizing large coefficients. This tends to drive coefficients to small, nonzero values. If you use this parameter, start by specifying a small value, such as 1.0E-08. The value is a double that ranges from 0 to MAX_DOUBLE. The default is to not use L2 normalization. This parameter can't be used when L1 is specified. Use this parameter sparingly.  . Defaults to None.
        training_data_source_id(str): The DataSource that points to the training data.
        recipe(str, optional): The data recipe for creating the MLModel. You must specify either the recipe or its URI. If you don't specify a recipe or its URI, Amazon ML creates a default. Defaults to None.
        recipe_uri(str, optional): The Amazon Simple Storage Service (Amazon S3) location and file name that contains the MLModel recipe. You must specify either the recipe or its URI. If you don't specify a recipe or its URI, Amazon ML creates a default. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.machinelearning.ml_model.create(
                ctx, ml_model_id=value, ml_model_type=value, training_data_source_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.machinelearning.ml_model.create ml_model_id=value, ml_model_type=value, training_data_source_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="machinelearning",
        operation="create_ml_model",
        op_kwargs={
            "MLModelId": ml_model_id,
            "MLModelName": ml_model_name,
            "MLModelType": ml_model_type,
            "Parameters": parameters,
            "TrainingDataSourceId": training_data_source_id,
            "Recipe": recipe,
            "RecipeUri": recipe_uri,
        },
    )


async def delete(hub, ctx, ml_model_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Assigns the DELETED status to an MLModel, rendering it unusable. After using the DeleteMLModel operation, you can use the GetMLModel operation to verify that the status of the MLModel changed to DELETED.  Caution: The result of the DeleteMLModel operation is irreversible.

    Args:
        ml_model_id(str): A user-supplied ID that uniquely identifies the MLModel.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.machinelearning.ml_model.delete(ctx, ml_model_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.machinelearning.ml_model.delete ml_model_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="machinelearning",
        operation="delete_ml_model",
        op_kwargs={"MLModelId": ml_model_id},
    )


async def describe_all(
    hub,
    ctx,
    filter_variable: str = None,
    eq: str = None,
    gt: str = None,
    lt: str = None,
    ge: str = None,
    le: str = None,
    ne: str = None,
    prefix: str = None,
    sort_order: str = None,
    next_token: str = None,
    limit: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of MLModel that match the search criteria in the request.

    Args:
        filter_variable(str, optional): Use one of the following variables to filter a list of MLModel:    CreatedAt - Sets the search criteria to MLModel creation date.    Status - Sets the search criteria to MLModel status.    Name - Sets the search criteria to the contents of MLModel   Name.    IAMUser - Sets the search criteria to the user account that invoked the MLModel creation.    TrainingDataSourceId - Sets the search criteria to the DataSource used to train one or more MLModel.    RealtimeEndpointStatus - Sets the search criteria to the MLModel real-time endpoint status.    MLModelType - Sets the search criteria to MLModel type: binary, regression, or multi-class.    Algorithm - Sets the search criteria to the algorithm that the MLModel uses.    TrainingDataURI - Sets the search criteria to the data file(s) used in training a MLModel. The URL can identify either a file or an Amazon Simple Storage Service (Amazon S3) bucket or directory.  . Defaults to None.
        eq(str, optional): The equal to operator. The MLModel results will have FilterVariable values that exactly match the value specified with EQ. Defaults to None.
        gt(str, optional): The greater than operator. The MLModel results will have FilterVariable values that are greater than the value specified with GT. Defaults to None.
        lt(str, optional): The less than operator. The MLModel results will have FilterVariable values that are less than the value specified with LT. Defaults to None.
        ge(str, optional): The greater than or equal to operator. The MLModel results will have FilterVariable values that are greater than or equal to the value specified with GE. . Defaults to None.
        le(str, optional): The less than or equal to operator. The MLModel results will have FilterVariable values that are less than or equal to the value specified with LE. Defaults to None.
        ne(str, optional): The not equal to operator. The MLModel results will have FilterVariable values not equal to the value specified with NE. Defaults to None.
        prefix(str, optional): A string that is found at the beginning of a variable, such as Name or Id. For example, an MLModel could have the Name 2014-09-09-HolidayGiftMailer. To search for this MLModel, select Name for the FilterVariable and any of the following strings for the Prefix:    2014-09   2014-09-09   2014-09-09-Holiday  . Defaults to None.
        sort_order(str, optional): A two-value parameter that determines the sequence of the resulting list of MLModel.    asc - Arranges the list in ascending order (A-Z, 0-9).    dsc - Arranges the list in descending order (Z-A, 9-0).   Results are sorted by FilterVariable. Defaults to None.
        next_token(str, optional): The ID of the page in the paginated results. Defaults to None.
        limit(int, optional): The number of pages of information to include in the result. The range of acceptable values is 1 through 100. The default value is 100. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.machinelearning.ml_model.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.machinelearning.ml_model.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="machinelearning",
        operation="describe_ml_models",
        op_kwargs={
            "FilterVariable": filter_variable,
            "EQ": eq,
            "GT": gt,
            "LT": lt,
            "GE": ge,
            "LE": le,
            "NE": ne,
            "Prefix": prefix,
            "SortOrder": sort_order,
            "NextToken": next_token,
            "Limit": limit,
        },
    )


async def get(hub, ctx, ml_model_id: str, verbose: bool = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns an MLModel that includes detailed metadata, data source information, and the current status of the MLModel.  GetMLModel provides results in normal or verbose format.

    Args:
        ml_model_id(str): The ID assigned to the MLModel at creation.
        verbose(bool, optional): Specifies whether the GetMLModel operation should return Recipe. If true, Recipe is returned. If false, Recipe is not returned. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.machinelearning.ml_model.get(ctx, ml_model_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.machinelearning.ml_model.get ml_model_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="machinelearning",
        operation="get_ml_model",
        op_kwargs={"MLModelId": ml_model_id, "Verbose": verbose},
    )


async def update(
    hub, ctx, ml_model_id: str, ml_model_name: str = None, score_threshold: float = None
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the MLModelName and the ScoreThreshold of an MLModel. You can use the GetMLModel operation to view the contents of the updated data element.

    Args:
        ml_model_id(str): The ID assigned to the MLModel during creation.
        ml_model_name(str, optional): A user-supplied name or description of the MLModel. Defaults to None.
        score_threshold(float, optional): The ScoreThreshold used in binary classification MLModel that marks the boundary between a positive prediction and a negative prediction. Output values greater than or equal to the ScoreThreshold receive a positive result from the MLModel, such as true. Output values less than the ScoreThreshold receive a negative response from the MLModel, such as false. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.machinelearning.ml_model.update(ctx, ml_model_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.machinelearning.ml_model.update ml_model_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="machinelearning",
        operation="update_ml_model",
        op_kwargs={
            "MLModelId": ml_model_id,
            "MLModelName": ml_model_name,
            "ScoreThreshold": score_threshold,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(
    hub,
    ctx,
    service_type: str,
    identifier: str,
    start_time: str,
    end_time: str,
    metric: str,
    group_by: Dict,
    period_in_seconds: int = None,
    partition_by: Dict = None,
    filter_: Dict = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    For a specific time period, retrieve the top N dimension keys for a metric.  Each response element returns a maximum of 500 bytes. For larger elements, such as SQL statements, only the first 500 bytes are returned.

    Args:
        service_type(str): The AWS service for which Performance Insights will return metrics. The only valid value for ServiceType is RDS.
        identifier(str): An immutable, AWS Region-unique identifier for a data source. Performance Insights gathers metrics from this data source. To use an Amazon RDS instance as a data source, you specify its DbiResourceId value. For example, specify db-FAIHNTYBKTGAUSUZQYPDS2GW4A .
        start_time(str): The date and time specifying the beginning of the requested time series data. You must specify a StartTime within the past 7 days. The value specified is inclusive, which means that data points equal to or greater than StartTime are returned. The value for StartTime must be earlier than the value for EndTime.
        end_time(str): The date and time specifying the end of the requested time series data. The value specified is exclusive, which means that data points less than (but not equal to) EndTime are returned. The value for EndTime must be later than the value for StartTime.
        metric(str): The name of a Performance Insights metric to be measured. Valid values for Metric are:    db.load.avg - a scaled representation of the number of active sessions for the database engine.    db.sampledload.avg - the raw number of active sessions for the database engine.   If the number of active sessions is less than an internal Performance Insights threshold, db.load.avg and db.sampledload.avg are the same value. If the number of active sessions is greater than the internal threshold, Performance Insights samples the active sessions, with db.load.avg showing the scaled values, db.sampledload.avg showing the raw values, and db.sampledload.avg less than db.load.avg. For most use cases, you can query db.load.avg only. .
        period_in_seconds(int, optional): The granularity, in seconds, of the data points returned from Performance Insights. A period can be as short as one second, or as long as one day (86400 seconds). Valid values are:    1 (one second)    60 (one minute)    300 (five minutes)    3600 (one hour)    86400 (twenty-four hours)   If you don't specify PeriodInSeconds, then Performance Insights chooses a value for you, with a goal of returning roughly 100-200 data points in the response. Defaults to None.
        group_by(Dict): A specification for how to aggregate the data points from a query result. You must specify a valid dimension group. Performance Insights returns all dimensions within this group, unless you provide the names of specific dimensions within this group. You can also request that Performance Insights return a limited number of values for a dimension.
        partition_by(Dict, optional): For each dimension specified in GroupBy, specify a secondary dimension to further subdivide the partition keys in the response. Defaults to None.
        filter_(Dict, optional): One or more filters to apply in the request. Restrictions:   Any number of filters by the same dimension, as specified in the GroupBy or Partition parameters.   A single filter for any other dimension in this dimension group.  . Defaults to None.
        max_results(int, optional): The maximum number of items to return in the response. If more items exist than the specified MaxRecords value, a pagination token is included in the response so that the remaining results can be retrieved. . Defaults to None.
        next_token(str, optional): An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the token, up to the value specified by MaxRecords. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.pi.dimension_key.init.describe_all(
                ctx,
                service_type=value,
                identifier=value,
                start_time=value,
                end_time=value,
                metric=value,
                group_by=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.pi.dimension_key.init.describe_all service_type=value, identifier=value, start_time=value, end_time=value, metric=value, group_by=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="pi",
        operation="describe_dimension_keys",
        op_kwargs={
            "ServiceType": service_type,
            "Identifier": identifier,
            "StartTime": start_time,
            "EndTime": end_time,
            "Metric": metric,
            "PeriodInSeconds": period_in_seconds,
            "GroupBy": group_by,
            "PartitionBy": partition_by,
            "Filter": filter_,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    cluster_identifier: str,
    feature_type: str,
    limit_type: str,
    amount: int,
    period: str = None,
    breach_action: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a usage limit for a specified Amazon Redshift feature on a cluster. The usage limit is identified by the returned usage limit identifier.

    Args:
        cluster_identifier(str): The identifier of the cluster that you want to limit usage.
        feature_type(str): The Amazon Redshift feature that you want to limit.
        limit_type(str): The type of limit. Depending on the feature type, this can be based on a time duration or data size. If FeatureType is spectrum, then LimitType must be data-scanned. If FeatureType is concurrency-scaling, then LimitType must be time. .
        amount(int): The limit amount. If time-based, this amount is in minutes. If data-based, this amount is in terabytes (TB). The value must be a positive number. .
        period(str, optional): The time period that the amount applies to. A weekly period begins on Sunday. The default is monthly. . Defaults to None.
        breach_action(str, optional): The action that Amazon Redshift takes when the limit is reached. The default is log. For more information about this parameter, see UsageLimit. Defaults to None.
        tags(List, optional): A list of tag instances. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.usage_limit.create(
                ctx, cluster_identifier=value, feature_type=value, limit_type=value, amount=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.usage_limit.create cluster_identifier=value, feature_type=value, limit_type=value, amount=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="create_usage_limit",
        op_kwargs={
            "ClusterIdentifier": cluster_identifier,
            "FeatureType": feature_type,
            "LimitType": limit_type,
            "Amount": amount,
            "Period": period,
            "BreachAction": breach_action,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, usage_limit_id: str) -> None:
    r"""
    **Autogenerated function**

    Deletes a usage limit from a cluster.

    Args:
        usage_limit_id(str): The identifier of the usage limit to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.usage_limit.delete(ctx, usage_limit_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.usage_limit.delete usage_limit_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="delete_usage_limit",
        op_kwargs={"UsageLimitId": usage_limit_id},
    )


async def describe_all(
    hub,
    ctx,
    usage_limit_id: str = None,
    cluster_identifier: str = None,
    feature_type: str = None,
    max_records: int = None,
    marker: str = None,
    tag_keys: List = None,
    tag_values: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Shows usage limits on a cluster. Results are filtered based on the combination of input usage limit identifier, cluster identifier, and feature type parameters:   If usage limit identifier, cluster identifier, and feature type are not provided, then all usage limit objects for the current account in the current region are returned.   If usage limit identifier is provided, then the corresponding usage limit object is returned.   If cluster identifier is provided, then all usage limit objects for the specified cluster are returned.   If cluster identifier and feature type are provided, then all usage limit objects for the combination of cluster and feature are returned.

    Args:
        usage_limit_id(str, optional): The identifier of the usage limit to describe. Defaults to None.
        cluster_identifier(str, optional): The identifier of the cluster for which you want to describe usage limits. Defaults to None.
        feature_type(str, optional): The feature type for which you want to describe usage limits. Defaults to None.
        max_records(int, optional): The maximum number of response records to return in each call. If the number of remaining response records exceeds the specified MaxRecords value, a value is returned in a marker field of the response. You can retrieve the next set of records by retrying the command with the returned marker value.  Default: 100  Constraints: minimum 20, maximum 100. Defaults to None.
        marker(str, optional): An optional parameter that specifies the starting point to return a set of response records. When the results of a DescribeUsageLimits request exceed the value specified in MaxRecords, Amazon Web Services returns a value in the Marker field of the response. You can retrieve the next set of response records by providing the returned marker value in the Marker parameter and retrying the request. . Defaults to None.
        tag_keys(List, optional): A tag key or keys for which you want to return all matching usage limit objects that are associated with the specified key or keys. For example, suppose that you have parameter groups that are tagged with keys called owner and environment. If you specify both of these tag keys in the request, Amazon Redshift returns a response with the usage limit objects have either or both of these tag keys associated with them. Defaults to None.
        tag_values(List, optional): A tag value or values for which you want to return all matching usage limit objects that are associated with the specified tag value or values. For example, suppose that you have parameter groups that are tagged with values called admin and test. If you specify both of these tag values in the request, Amazon Redshift returns a response with the usage limit objects that have either or both of these tag values associated with them. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.usage_limit.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.usage_limit.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="describe_usage_limits",
        op_kwargs={
            "UsageLimitId": usage_limit_id,
            "ClusterIdentifier": cluster_identifier,
            "FeatureType": feature_type,
            "MaxRecords": max_records,
            "Marker": marker,
            "TagKeys": tag_keys,
            "TagValues": tag_values,
        },
    )


async def modify(
    hub, ctx, usage_limit_id: str, amount: int = None, breach_action: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Modifies a usage limit in a cluster. You can't modify the feature type or period of a usage limit.

    Args:
        usage_limit_id(str): The identifier of the usage limit to modify.
        amount(int, optional): The new limit amount. For more information about this parameter, see UsageLimit. . Defaults to None.
        breach_action(str, optional): The new action that Amazon Redshift takes when the limit is reached. For more information about this parameter, see UsageLimit. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.usage_limit.modify(ctx, usage_limit_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.usage_limit.modify usage_limit_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="modify_usage_limit",
        op_kwargs={
            "UsageLimitId": usage_limit_id,
            "Amount": amount,
            "BreachAction": breach_action,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__func_alias__ = {"import_": "import"}


async def create(
    hub,
    ctx,
    name: str = None,
    description: str = None,
    enabled: bool = None,
    generate_distinct_id: bool = None,
    value: str = None,
    stage_keys: List = None,
    customer_id: str = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Create an ApiKey resource.  AWS CLI

    Args:
        name(str, optional): The name of the ApiKey. Defaults to None.
        description(str, optional): The description of the ApiKey. Defaults to None.
        enabled(bool, optional): Specifies whether the ApiKey can be used by callers. Defaults to None.
        generate_distinct_id(bool, optional): Specifies whether (true) or not (false) the key identifier is distinct from the created API key value. This parameter is deprecated and should not be used. Defaults to None.
        value(str, optional): Specifies a value of the API key. Defaults to None.
        stage_keys(List, optional): DEPRECATED FOR USAGE PLANS - Specifies stages associated with the API key. Defaults to None.
        customer_id(str, optional): An AWS Marketplace customer identifier , when integrating with the AWS SaaS Marketplace. Defaults to None.
        tags(Dict, optional): The key-value map of strings. The valid character set is [a-zA-Z+-=._:/]. The tag key can be up to 128 characters and must not start with aws:. The tag value can be up to 256 characters. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.api_key.create(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.api_key.create
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="create_api_key",
        op_kwargs={
            "name": name,
            "description": description,
            "enabled": enabled,
            "generateDistinctId": generate_distinct_id,
            "value": value,
            "stageKeys": stage_keys,
            "customerId": customer_id,
            "tags": tags,
        },
    )


async def delete(hub, ctx, api_key: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the ApiKey resource.

    Args:
        api_key(str): [Required] The identifier of the ApiKey resource to be deleted.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.api_key.delete(ctx, api_key=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.api_key.delete api_key=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="delete_api_key",
        op_kwargs={"apiKey": api_key},
    )


async def get(hub, ctx, api_key: str, include_value: bool = None) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about the current ApiKey resource.

    Args:
        api_key(str): [Required] The identifier of the ApiKey resource.
        include_value(bool, optional): A boolean flag to specify whether (true) or not (false) the result contains the key value. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.api_key.get(ctx, api_key=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.api_key.get api_key=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="get_api_key",
        op_kwargs={"apiKey": api_key, "includeValue": include_value},
    )


async def get_all(
    hub,
    ctx,
    position: str = None,
    limit: int = None,
    name_query: str = None,
    customer_id: str = None,
    include_values: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about the current ApiKeys resource.

    Args:
        position(str, optional): The current pagination position in the paged result set. Defaults to None.
        limit(int, optional): The maximum number of returned results per page. The default value is 25 and the maximum value is 500. Defaults to None.
        name_query(str, optional): The name of queried API keys. Defaults to None.
        customer_id(str, optional): The identifier of a customer in AWS Marketplace or an external system, such as a developer portal. Defaults to None.
        include_values(bool, optional): A boolean flag to specify whether (true) or not (false) the result contains key values. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.api_key.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.api_key.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="get_api_keys",
        op_kwargs={
            "position": position,
            "limit": limit,
            "nameQuery": name_query,
            "customerId": customer_id,
            "includeValues": include_values,
        },
    )


async def import_(
    hub, ctx, body: bytes, format_: str, fail_on_warnings: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Import API keys from an external source, such as a CSV-formatted file.

    Args:
        body(bytes): The payload of the POST request to import API keys. For the payload format, see API Key File Format.
        format_(str): A query parameter to specify the input format to imported API keys. Currently, only the csv format is supported.
        fail_on_warnings(bool, optional): A query parameter to indicate whether to rollback ApiKey importation (true) or not (false) when error is encountered. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.api_key.import(ctx, body=value, format_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.api_key.import body=value, format_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="import_api_keys",
        op_kwargs={"body": body, "format": format_, "failOnWarnings": fail_on_warnings},
    )


async def update(hub, ctx, api_key: str, patch_operations: List = None) -> Dict:
    r"""
    **Autogenerated function**

    Changes information about an ApiKey resource.

    Args:
        api_key(str): [Required] The identifier of the ApiKey resource to be updated.
        patch_operations(List, optional): A list of update operations to be applied to the specified resource and in the order specified in this list. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.api_key.update(ctx, api_key=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.api_key.update api_key=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="update_api_key",
        op_kwargs={"apiKey": api_key, "patchOperations": patch_operations},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx, comment_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the content of a comment made on a change, file, or commit in a repository.

    Args:
        comment_id(str): The unique, system-generated ID of the comment. To get this ID, use GetCommentsForComparedCommit or GetCommentsForPullRequest.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codecommit.comment.content.delete(ctx, comment_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codecommit.comment.content.delete comment_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codecommit",
        operation="delete_comment_content",
        op_kwargs={"commentId": comment_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def cancel(hub, ctx, cluster_identifier: str) -> Dict:
    r"""
    **Autogenerated function**

    Cancels a resize operation for a cluster.

    Args:
        cluster_identifier(str): The unique identifier for the cluster that you want to cancel a resize operation for.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.resize.cancel(ctx, cluster_identifier=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.resize.cancel cluster_identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="cancel_resize",
        op_kwargs={"ClusterIdentifier": cluster_identifier},
    )


async def describe(hub, ctx, cluster_identifier: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about the last resize operation for the specified cluster. If no resize operation has ever been initiated for the specified cluster, a HTTP 404 error is returned. If a resize operation was initiated and completed, the status of the resize remains as SUCCEEDED until the next resize.  A resize operation can be requested using ModifyCluster and specifying a different number or type of nodes for the cluster.

    Args:
        cluster_identifier(str): The unique identifier of a cluster whose resize progress you are requesting. This parameter is case-sensitive. By default, resize operations for all clusters defined for an Amazon Web Services account are returned.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.resize.describe(ctx, cluster_identifier=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.resize.describe cluster_identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="describe_resize",
        op_kwargs={"ClusterIdentifier": cluster_identifier},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def update(hub, ctx, gateway_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Updates the gateway virtual machine (VM) software. The request immediately triggers the software update.  When you make this request, you get a 200 OK success response immediately. However, it might take some time for the update to complete. You can call DescribeGatewayInformation to verify the gateway is in the STATE_RUNNING state.   A software update forces a system restart of your gateway. You can minimize the chance of any disruption to your applications by increasing your iSCSI Initiators' timeouts. For more information about increasing iSCSI Initiator timeouts for Windows and Linux, see Customizing your Windows iSCSI settings and Customizing your Linux iSCSI settings, respectively.

    Args:
        gateway_arn(str): The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and Region.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.storagegateway.gateway.software_now.update(
                ctx, gateway_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.storagegateway.gateway.software_now.update gateway_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="storagegateway",
        operation="update_gateway_software_now",
        op_kwargs={"GatewayARN": gateway_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def deregister(
    hub,
    ctx,
    stream_arn: str = None,
    consumer_name: str = None,
    consumer_arn: str = None,
) -> None:
    r"""
    **Autogenerated function**

    To deregister a consumer, provide its ARN. Alternatively, you can provide the ARN of the data stream and the name you gave the consumer when you registered it. You may also provide all three parameters, as long as they don't conflict with each other. If you don't know the name or ARN of the consumer that you want to deregister, you can use the ListStreamConsumers operation to get a list of the descriptions of all the consumers that are currently registered with a given data stream. The description of a consumer contains its name and ARN. This operation has a limit of five transactions per second per stream.

    Args:
        stream_arn(str, optional): The ARN of the Kinesis data stream that the consumer is registered with. For more information, see Amazon Resource Names (ARNs) and AWS Service Namespaces. Defaults to None.
        consumer_name(str, optional): The name that you gave to the consumer. Defaults to None.
        consumer_arn(str, optional): The ARN returned by Kinesis Data Streams when you registered the consumer. If you don't know the ARN of the consumer that you want to deregister, you can use the ListStreamConsumers operation to get a list of the descriptions of all the consumers that are currently registered with a given data stream. The description of a consumer contains its ARN. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesis.stream.consumer.deregister(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesis.stream.consumer.deregister
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesis",
        operation="deregister_stream_consumer",
        op_kwargs={
            "StreamARN": stream_arn,
            "ConsumerName": consumer_name,
            "ConsumerARN": consumer_arn,
        },
    )


async def describe(
    hub,
    ctx,
    stream_arn: str = None,
    consumer_name: str = None,
    consumer_arn: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    To get the description of a registered consumer, provide the ARN of the consumer. Alternatively, you can provide the ARN of the data stream and the name you gave the consumer when you registered it. You may also provide all three parameters, as long as they don't conflict with each other. If you don't know the name or ARN of the consumer that you want to describe, you can use the ListStreamConsumers operation to get a list of the descriptions of all the consumers that are currently registered with a given data stream. This operation has a limit of 20 transactions per second per stream.

    Args:
        stream_arn(str, optional): The ARN of the Kinesis data stream that the consumer is registered with. For more information, see Amazon Resource Names (ARNs) and AWS Service Namespaces. Defaults to None.
        consumer_name(str, optional): The name that you gave to the consumer. Defaults to None.
        consumer_arn(str, optional): The ARN returned by Kinesis Data Streams when you registered the consumer. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesis.stream.consumer.describe(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesis.stream.consumer.describe
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesis",
        operation="describe_stream_consumer",
        op_kwargs={
            "StreamARN": stream_arn,
            "ConsumerName": consumer_name,
            "ConsumerARN": consumer_arn,
        },
    )


async def list_all(
    hub,
    ctx,
    stream_arn: str,
    next_token: str = None,
    max_results: int = None,
    stream_creation_timestamp: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the consumers registered to receive data from a stream using enhanced fan-out, and provides information about each consumer. This operation has a limit of 5 transactions per second per stream.

    Args:
        stream_arn(str): The ARN of the Kinesis data stream for which you want to list the registered consumers. For more information, see Amazon Resource Names (ARNs) and AWS Service Namespaces.
        next_token(str, optional): When the number of consumers that are registered with the data stream is greater than the default value for the MaxResults parameter, or if you explicitly specify a value for MaxResults that is less than the number of consumers that are registered with the data stream, the response includes a pagination token named NextToken. You can specify this NextToken value in a subsequent call to ListStreamConsumers to list the next set of registered consumers. Don't specify StreamName or StreamCreationTimestamp if you specify NextToken because the latter unambiguously identifies the stream. You can optionally specify a value for the MaxResults parameter when you specify NextToken. If you specify a MaxResults value that is less than the number of consumers that the operation returns if you don't specify MaxResults, the response will contain a new NextToken value. You can use the new NextToken value in a subsequent call to the ListStreamConsumers operation to list the next set of consumers.  Tokens expire after 300 seconds. When you obtain a value for NextToken in the response to a call to ListStreamConsumers, you have 300 seconds to use that value. If you specify an expired token in a call to ListStreamConsumers, you get ExpiredNextTokenException. . Defaults to None.
        max_results(int, optional): The maximum number of consumers that you want a single call of ListStreamConsumers to return. Defaults to None.
        stream_creation_timestamp(str, optional): Specify this input parameter to distinguish data streams that have the same name. For example, if you create a data stream and then delete it, and you later create another data stream with the same name, you can use this input parameter to specify which of the two streams you want to list the consumers for.  You can't specify this parameter if you specify the NextToken parameter. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesis.stream.consumer.list_all(ctx, stream_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesis.stream.consumer.list_all stream_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesis",
        operation="list_stream_consumers",
        op_kwargs={
            "StreamARN": stream_arn,
            "NextToken": next_token,
            "MaxResults": max_results,
            "StreamCreationTimestamp": stream_creation_timestamp,
        },
    )


async def register(hub, ctx, stream_arn: str, consumer_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Registers a consumer with a Kinesis data stream. When you use this operation, the consumer you register can then call SubscribeToShard to receive data from the stream using enhanced fan-out, at a rate of up to 2 MiB per second for every shard you subscribe to. This rate is unaffected by the total number of consumers that read from the same stream. You can register up to 20 consumers per stream. A given consumer can only be registered with one stream at a time. For an example of how to use this operations, see Enhanced Fan-Out Using the Kinesis Data Streams API. The use of this operation has a limit of five transactions per second per account. Also, only 5 consumers can be created simultaneously. In other words, you cannot have more than 5 consumers in a CREATING status at the same time. Registering a 6th consumer while there are 5 in a CREATING status results in a LimitExceededException.

    Args:
        stream_arn(str): The ARN of the Kinesis data stream that you want to register the consumer with. For more info, see Amazon Resource Names (ARNs) and AWS Service Namespaces.
        consumer_name(str): For a given Kinesis data stream, each consumer must have a unique name. However, consumer names don't have to be unique across data streams.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesis.stream.consumer.register(
                ctx, stream_arn=value, consumer_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesis.stream.consumer.register stream_arn=value, consumer_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesis",
        operation="register_stream_consumer",
        op_kwargs={"StreamARN": stream_arn, "ConsumerName": consumer_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    amzn_client_token: str = None,
    initial_version: Dict = None,
    name: str = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a resource definition which contains a list of resources to be used in a group. You can create an initial version of the definition by providing a list of resources now, or use ''CreateResourceDefinitionVersion'' later.

    Args:
        amzn_client_token(str, optional): A client token used to correlate requests and responses. Defaults to None.
        initial_version(Dict, optional): Information about the initial version of the resource definition. Defaults to None.
        name(str, optional): The name of the resource definition. Defaults to None.
        tags(Dict, optional): Tag(s) to add to the new resource. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.greengrass.resource.definition.init.create(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.greengrass.resource.definition.init.create
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="greengrass",
        operation="create_resource_definition",
        op_kwargs={
            "AmznClientToken": amzn_client_token,
            "InitialVersion": initial_version,
            "Name": name,
            "tags": tags,
        },
    )


async def delete(hub, ctx, resource_definition_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a resource definition.

    Args:
        resource_definition_id(str): The ID of the resource definition.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.greengrass.resource.definition.init.delete(
                ctx, resource_definition_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.greengrass.resource.definition.init.delete resource_definition_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="greengrass",
        operation="delete_resource_definition",
        op_kwargs={"ResourceDefinitionId": resource_definition_id},
    )


async def get(hub, ctx, resource_definition_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information about a resource definition, including its creation time and latest version.

    Args:
        resource_definition_id(str): The ID of the resource definition.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.greengrass.resource.definition.init.get(
                ctx, resource_definition_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.greengrass.resource.definition.init.get resource_definition_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="greengrass",
        operation="get_resource_definition",
        op_kwargs={"ResourceDefinitionId": resource_definition_id},
    )


async def list_all(hub, ctx, max_results: str = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a list of resource definitions.

    Args:
        max_results(str, optional): The maximum number of results to be returned per request. Defaults to None.
        next_token(str, optional): The token for the next set of results, or ''null'' if there are no additional results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.greengrass.resource.definition.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.greengrass.resource.definition.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="greengrass",
        operation="list_resource_definitions",
        op_kwargs={"MaxResults": max_results, "NextToken": next_token},
    )


async def update(hub, ctx, resource_definition_id: str, name: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Updates a resource definition.

    Args:
        name(str, optional): The name of the definition. Defaults to None.
        resource_definition_id(str): The ID of the resource definition.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.greengrass.resource.definition.init.update(
                ctx, resource_definition_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.greengrass.resource.definition.init.update resource_definition_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="greengrass",
        operation="update_resource_definition",
        op_kwargs={"Name": name, "ResourceDefinitionId": resource_definition_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""


async def update(hub, ctx, configuration_set_name: str, enabled: bool) -> None:
    r"""
    **Autogenerated function**

    Enables or disables the publishing of reputation metrics for emails sent using a specific configuration set in a given AWS Region. Reputation metrics include bounce and complaint rates. These metrics are published to Amazon CloudWatch. By using CloudWatch, you can create alarms when bounce or complaint rates exceed certain thresholds. You can execute this operation no more than once per second.

    Args:
        configuration_set_name(str): The name of the configuration set that you want to update.
        enabled(bool): Describes whether or not Amazon SES will publish reputation metrics for the configuration set, such as bounce and complaint rates, to Amazon CloudWatch.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ses.configuration_set_.reputation_metric_enabled.update(
                ctx, configuration_set_name=value, enabled=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ses.configuration_set_.reputation_metric_enabled.update configuration_set_name=value, enabled=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ses",
        operation="update_configuration_set_reputation_metrics_enabled",
        op_kwargs={"ConfigurationSetName": configuration_set_name, "Enabled": enabled},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def disassociate(
    hub, ctx, voice_connector_group_id: str, e164_phone_numbers: List
) -> Dict:
    r"""
    **Autogenerated function**

    Disassociates the specified phone numbers from the specified Amazon Chime Voice Connector group.

    Args:
        voice_connector_group_id(str): The Amazon Chime Voice Connector group ID.
        e164_phone_numbers(List): List of phone numbers, in E.164 format.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.phone_number.from_.voice_connector.group.disassociate(
                ctx, voice_connector_group_id=value, e164_phone_numbers=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.phone_number.from_.voice_connector.group.disassociate voice_connector_group_id=value, e164_phone_numbers=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="disassociate_phone_numbers_from_voice_connector_group",
        op_kwargs={
            "VoiceConnectorGroupId": voice_connector_group_id,
            "E164PhoneNumbers": e164_phone_numbers,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def send(hub, ctx, task_token: str) -> Dict:
    r"""
    **Autogenerated function**

    Used by activity workers and task states using the callback pattern to report to Step Functions that the task represented by the specified taskToken is still making progress. This action resets the Heartbeat clock. The Heartbeat threshold is specified in the state machine's Amazon States Language definition (HeartbeatSeconds). This action does not in itself create an event in the execution history. However, if the task times out, the execution history contains an ActivityTimedOut entry for activities, or a TaskTimedOut entry for for tasks using the job run or callback pattern.  The Timeout of a task, defined in the state machine's Amazon States Language definition, is its maximum allowed duration, regardless of the number of SendTaskHeartbeat requests received. Use HeartbeatSeconds to configure the timeout interval for heartbeats.

    Args:
        task_token(str): The token that represents this task. Task tokens are generated by Step Functions when tasks are assigned to a worker, or in the context object when a workflow enters a task state. See GetActivityTaskOutput$taskToken.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.stepfunction.task.heartbeat.send(ctx, task_token=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.stepfunction.task.heartbeat.send task_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="stepfunctions",
        operation="send_task_heartbeat",
        op_kwargs={"taskToken": task_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx, asset_id: str, property_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information about an asset property.  When you call this operation for an attribute property, this response includes the default attribute value that you define in the asset model. If you update the default value in the model, this operation's response includes the new default value.  This operation doesn't return the value of the asset property. To get the value of an asset property, use GetAssetPropertyValue.

    Args:
        asset_id(str): The ID of the asset.
        property_id(str): The ID of the asset property.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotsitewise.asset.property_.init.describe(
                ctx, asset_id=value, property_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotsitewise.asset.property_.init.describe asset_id=value, property_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotsitewise",
        operation="describe_asset_property",
        op_kwargs={"assetId": asset_id, "propertyId": property_id},
    )


async def update(
    hub,
    ctx,
    asset_id: str,
    property_id: str,
    property_alias: str = None,
    property_notification_state: str = None,
    client_token: str = None,
) -> None:
    r"""
    **Autogenerated function**

    Updates an asset property's alias and notification state.  This operation overwrites the property's existing alias and notification state. To keep your existing property's alias or notification state, you must include the existing values in the UpdateAssetProperty request. For more information, see DescribeAssetProperty.

    Args:
        asset_id(str): The ID of the asset to be updated.
        property_id(str): The ID of the asset property to be updated.
        property_alias(str, optional): The alias that identifies the property, such as an OPC-UA server data stream path (for example, /company/windfarm/3/turbine/7/temperature). For more information, see Mapping industrial data streams to asset properties in the IoT SiteWise User Guide. If you omit this parameter, the alias is removed from the property. Defaults to None.
        property_notification_state(str, optional): The MQTT notification state (enabled or disabled) for this asset property. When the notification state is enabled, IoT SiteWise publishes property value updates to a unique MQTT topic. For more information, see Interacting with other services in the IoT SiteWise User Guide. If you omit this parameter, the notification state is set to DISABLED. Defaults to None.
        client_token(str, optional): A unique case-sensitive identifier that you can provide to ensure the idempotency of the request. Don't reuse this client token if a new idempotent request is required. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotsitewise.asset.property_.init.update(
                ctx, asset_id=value, property_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotsitewise.asset.property_.init.update asset_id=value, property_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotsitewise",
        operation="update_asset_property",
        op_kwargs={
            "assetId": asset_id,
            "propertyId": property_id,
            "propertyAlias": property_alias,
            "propertyNotificationState": property_notification_state,
            "clientToken": client_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def associate(
    hub, ctx, global_network_id: str, device_id: str, link_id: str
) -> Dict:
    r"""
    **Autogenerated function**

    Associates a link to a device. A device can be associated to multiple links and a link can be associated to multiple devices. The device and link must be in the same global network and the same site.

    Args:
        global_network_id(str): The ID of the global network.
        device_id(str): The ID of the device.
        link_id(str): The ID of the link.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.networkmanager.link.init.associate(
                ctx, global_network_id=value, device_id=value, link_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.networkmanager.link.init.associate global_network_id=value, device_id=value, link_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="networkmanager",
        operation="associate_link",
        op_kwargs={
            "GlobalNetworkId": global_network_id,
            "DeviceId": device_id,
            "LinkId": link_id,
        },
    )


async def create(
    hub,
    ctx,
    global_network_id: str,
    bandwidth: Dict,
    site_id: str,
    description: str = None,
    type_: str = None,
    provider: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new link for a specified site.

    Args:
        global_network_id(str): The ID of the global network.
        description(str, optional): A description of the link. Length Constraints: Maximum length of 256 characters. Defaults to None.
        type_(str, optional): The type of the link. Constraints: Cannot include the following characters: | \ ^ Length Constraints: Maximum length of 128 characters. Defaults to None.
        bandwidth(Dict):  The upload speed and download speed in Mbps. .
        provider(str, optional): The provider of the link. Constraints: Cannot include the following characters: | \ ^ Length Constraints: Maximum length of 128 characters. Defaults to None.
        site_id(str): The ID of the site.
        tags(List, optional): The tags to apply to the resource during creation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.networkmanager.link.init.create(
                ctx, global_network_id=value, bandwidth=value, site_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.networkmanager.link.init.create global_network_id=value, bandwidth=value, site_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="networkmanager",
        operation="create_link",
        op_kwargs={
            "GlobalNetworkId": global_network_id,
            "Description": description,
            "Type": type_,
            "Bandwidth": bandwidth,
            "Provider": provider,
            "SiteId": site_id,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, global_network_id: str, link_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an existing link. You must first disassociate the link from any devices and customer gateways.

    Args:
        global_network_id(str): The ID of the global network.
        link_id(str): The ID of the link.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.networkmanager.link.init.delete(
                ctx, global_network_id=value, link_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.networkmanager.link.init.delete global_network_id=value, link_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="networkmanager",
        operation="delete_link",
        op_kwargs={"GlobalNetworkId": global_network_id, "LinkId": link_id},
    )


async def disassociate(
    hub, ctx, global_network_id: str, device_id: str, link_id: str
) -> Dict:
    r"""
    **Autogenerated function**

    Disassociates an existing device from a link. You must first disassociate any customer gateways that are associated with the link.

    Args:
        global_network_id(str): The ID of the global network.
        device_id(str): The ID of the device.
        link_id(str): The ID of the link.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.networkmanager.link.init.disassociate(
                ctx, global_network_id=value, device_id=value, link_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.networkmanager.link.init.disassociate global_network_id=value, device_id=value, link_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="networkmanager",
        operation="disassociate_link",
        op_kwargs={
            "GlobalNetworkId": global_network_id,
            "DeviceId": device_id,
            "LinkId": link_id,
        },
    )


async def get_all(
    hub,
    ctx,
    global_network_id: str,
    link_ids: List = None,
    site_id: str = None,
    type_: str = None,
    provider: str = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about one or more links in a specified global network. If you specify the site ID, you cannot specify the type or provider in the same request. You can specify the type and provider in the same request.

    Args:
        global_network_id(str): The ID of the global network.
        link_ids(List, optional): One or more link IDs. The maximum is 10. Defaults to None.
        site_id(str, optional): The ID of the site. Defaults to None.
        type_(str, optional): The link type. Defaults to None.
        provider(str, optional): The link provider. Defaults to None.
        max_results(int, optional): The maximum number of results to return. Defaults to None.
        next_token(str, optional): The token for the next page of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.networkmanager.link.init.get_all(ctx, global_network_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.networkmanager.link.init.get_all global_network_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="networkmanager",
        operation="get_links",
        op_kwargs={
            "GlobalNetworkId": global_network_id,
            "LinkIds": link_ids,
            "SiteId": site_id,
            "Type": type_,
            "Provider": provider,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def update(
    hub,
    ctx,
    global_network_id: str,
    link_id: str,
    description: str = None,
    type_: str = None,
    bandwidth: Dict = None,
    provider: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the details for an existing link. To remove information for any of the parameters, specify an empty string.

    Args:
        global_network_id(str): The ID of the global network.
        link_id(str): The ID of the link.
        description(str, optional): A description of the link. Length Constraints: Maximum length of 256 characters. Defaults to None.
        type_(str, optional): The type of the link. Length Constraints: Maximum length of 128 characters. Defaults to None.
        bandwidth(Dict, optional): The upload and download speed in Mbps. . Defaults to None.
        provider(str, optional): The provider of the link. Length Constraints: Maximum length of 128 characters. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.networkmanager.link.init.update(
                ctx, global_network_id=value, link_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.networkmanager.link.init.update global_network_id=value, link_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="networkmanager",
        operation="update_link",
        op_kwargs={
            "GlobalNetworkId": global_network_id,
            "LinkId": link_id,
            "Description": description,
            "Type": type_,
            "Bandwidth": bandwidth,
            "Provider": provider,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(
    hub, ctx, insight_id: str, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    X-Ray reevaluates insights periodically until they're resolved, and records each intermediate state as an event. You can review an insight's events in the Impact Timeline on the Inspect page in the X-Ray console.

    Args:
        insight_id(str): The insight's unique identifier. Use the GetInsightSummaries action to retrieve an InsightId.
        max_results(int, optional): Used to retrieve at most the specified value of events. Defaults to None.
        next_token(str, optional): Specify the pagination token returned by a previous request to retrieve the next page of events. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.xray.insight.event.get_all(ctx, insight_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.xray.insight.event.get_all insight_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="xray",
        operation="get_insight_events",
        op_kwargs={
            "InsightId": insight_id,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    name: str,
    control_sets: List,
    description: str = None,
    compliance_type: str = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Creates a custom framework in Audit Manager.

    Args:
        name(str):  The name of the new custom framework. .
        description(str, optional):  An optional description for the new custom framework. . Defaults to None.
        compliance_type(str, optional):  The compliance type that the new custom framework supports, such as CIS or HIPAA. . Defaults to None.
        control_sets(List):  The control sets to be associated with the framework. .
        tags(Dict, optional):  The tags associated with the framework. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.auditmanager.assessment.framework.create(
                ctx, name=value, control_sets=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.auditmanager.assessment.framework.create name=value, control_sets=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="auditmanager",
        operation="create_assessment_framework",
        op_kwargs={
            "name": name,
            "description": description,
            "complianceType": compliance_type,
            "controlSets": control_sets,
            "tags": tags,
        },
    )


async def delete(hub, ctx, framework_id: str) -> Dict:
    r"""
    **Autogenerated function**

     Deletes a custom framework in Audit Manager.

    Args:
        framework_id(str):  The identifier for the specified framework. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.auditmanager.assessment.framework.delete(
                ctx, framework_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.auditmanager.assessment.framework.delete framework_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="auditmanager",
        operation="delete_assessment_framework",
        op_kwargs={"frameworkId": framework_id},
    )


async def get(hub, ctx, framework_id: str) -> Dict:
    r"""
    **Autogenerated function**

     Returns a framework from Audit Manager.

    Args:
        framework_id(str):  The identifier for the specified framework. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.auditmanager.assessment.framework.get(ctx, framework_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.auditmanager.assessment.framework.get framework_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="auditmanager",
        operation="get_assessment_framework",
        op_kwargs={"frameworkId": framework_id},
    )


async def list_all(
    hub, ctx, framework_type: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

     Returns a list of the frameworks available in the Audit Manager framework library.

    Args:
        framework_type(str):  The type of framework, such as standard or custom. .
        next_token(str, optional):  The pagination token used to fetch the next set of results. . Defaults to None.
        max_results(int, optional):  Represents the maximum number of results per page, or per API request call. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.auditmanager.assessment.framework.list_all(
                ctx, framework_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.auditmanager.assessment.framework.list_all framework_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="auditmanager",
        operation="list_assessment_frameworks",
        op_kwargs={
            "frameworkType": framework_type,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )


async def update(
    hub,
    ctx,
    framework_id: str,
    name: str,
    control_sets: List,
    description: str = None,
    compliance_type: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Updates a custom framework in Audit Manager.

    Args:
        framework_id(str):  The identifier for the specified framework. .
        name(str):  The name of the framework to be updated. .
        description(str, optional):  The description of the framework that is to be updated. . Defaults to None.
        compliance_type(str, optional):  The compliance type that the new custom framework supports, such as CIS or HIPAA. . Defaults to None.
        control_sets(List):  The control sets associated with the framework. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.auditmanager.assessment.framework.update(
                ctx, framework_id=value, name=value, control_sets=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.auditmanager.assessment.framework.update framework_id=value, name=value, control_sets=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="auditmanager",
        operation="update_assessment_framework",
        op_kwargs={
            "frameworkId": framework_id,
            "name": name,
            "description": description,
            "complianceType": compliance_type,
            "controlSets": control_sets,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def put_multiple(
    hub, ctx, result_token: str, evaluations: List = None, test_mode: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Used by an AWS Lambda function to deliver evaluation results to AWS Config. This action is required in every AWS Lambda function that is invoked by an AWS Config rule.

    Args:
        evaluations(List, optional): The assessments that the AWS Lambda function performs. Each evaluation identifies an AWS resource and indicates whether it complies with the AWS Config rule that invokes the AWS Lambda function. Defaults to None.
        result_token(str): An encrypted token that associates an evaluation with an AWS Config rule. Identifies the rule and the event that triggered the evaluation.
        test_mode(bool, optional): Use this parameter to specify a test run for PutEvaluations. You can verify whether your AWS Lambda function will deliver evaluation results to AWS Config. No updates occur to your existing evaluations, and evaluation results are not sent to AWS Config.  When TestMode is true, PutEvaluations doesn't require a valid value for the ResultToken parameter, but the value cannot be null. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.config.evaluation.init.put_multiple(ctx, result_token=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.config.evaluation.init.put_multiple result_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="config",
        operation="put_evaluations",
        op_kwargs={
            "Evaluations": evaluations,
            "ResultToken": result_token,
            "TestMode": test_mode,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def add(hub, ctx, gateway_arn: str, disk_ids: List) -> Dict:
    r"""
    **Autogenerated function**

    Configures one or more gateway local disks as working storage for a gateway. This operation is only supported in the stored volume gateway type. This operation is deprecated in cached volume API version 20120630. Use AddUploadBuffer instead.  Working storage is also referred to as upload buffer. You can also use the AddUploadBuffer operation to add upload buffer to a stored volume gateway.  In the request, you specify the gateway Amazon Resource Name (ARN) to which you want to add working storage, and one or more disk IDs that you want to configure as working storage.

    Args:
        gateway_arn(str): The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and Region.
        disk_ids(List): An array of strings that identify disks that are to be configured as working storage. Each string has a minimum length of 1 and maximum length of 300. You can get the disk IDs from the ListLocalDisks API.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.storagegateway.working_storage.add(
                ctx, gateway_arn=value, disk_ids=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.storagegateway.working_storage.add gateway_arn=value, disk_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="storagegateway",
        operation="add_working_storage",
        op_kwargs={"GatewayARN": gateway_arn, "DiskIds": disk_ids},
    )


async def describe(hub, ctx, gateway_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about the working storage of a gateway. This operation is only supported in the stored volumes gateway type. This operation is deprecated in cached volumes API version (20120630). Use DescribeUploadBuffer instead.  Working storage is also referred to as upload buffer. You can also use the DescribeUploadBuffer operation to add upload buffer to a stored volume gateway.  The response includes disk IDs that are configured as working storage, and it includes the amount of working storage allocated and used.

    Args:
        gateway_arn(str): The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and Region.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.storagegateway.working_storage.describe(ctx, gateway_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.storagegateway.working_storage.describe gateway_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="storagegateway",
        operation="describe_working_storage",
        op_kwargs={"GatewayARN": gateway_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the playback configuration for the specified name.

    Args:
        name(str): The identifier for the playback configuration.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediatailor.playback_configuration.delete(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediatailor.playback_configuration.delete name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediatailor",
        operation="delete_playback_configuration",
        op_kwargs={"Name": name},
    )


async def get(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns the playback configuration for the specified name.

    Args:
        name(str): The identifier for the playback configuration.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediatailor.playback_configuration.get(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediatailor.playback_configuration.get name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediatailor",
        operation="get_playback_configuration",
        op_kwargs={"Name": name},
    )


async def list_all(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of the playback configurations defined in AWS Elemental MediaTailor. You can specify a maximum number of configurations to return at a time. The default maximum is 50. Results are returned in pagefuls. If MediaTailor has more configurations than the specified maximum, it provides parameters in the response that you can use to retrieve the next pageful.

    Args:
        max_results(int, optional): Maximum number of records to return. Defaults to None.
        next_token(str, optional): Pagination token returned by the GET list request when results exceed the maximum allowed. Use the token to fetch the next page of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediatailor.playback_configuration.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediatailor.playback_configuration.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediatailor",
        operation="list_playback_configurations",
        op_kwargs={"MaxResults": max_results, "NextToken": next_token},
    )


async def put(
    hub,
    ctx,
    ad_decision_server_url: str = None,
    avail_suppression: Dict = None,
    bumper: Dict = None,
    cdn_configuration: Dict = None,
    configuration_aliases: Dict = None,
    dash_configuration: Dict = None,
    live_pre_roll_configuration: Dict = None,
    manifest_processing_rules: Dict = None,
    name: str = None,
    personalization_threshold_seconds: int = None,
    slate_ad_url: str = None,
    tags: Dict = None,
    transcode_profile_name: str = None,
    video_content_source_url: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Adds a new playback configuration to AWS Elemental MediaTailor.

    Args:
        ad_decision_server_url(str, optional): The URL for the ad decision server (ADS). This includes the specification of static parameters and placeholders for dynamic parameters. AWS Elemental MediaTailor substitutes player-specific and session-specific parameters as needed when calling the ADS. Alternately, for testing you can provide a static VAST URL. The maximum length is 25,000 characters. Defaults to None.
        avail_suppression(Dict, optional): The configuration for avail suppression, also known as ad suppression. For more information about ad suppression, see Ad Suppression. Defaults to None.
        bumper(Dict, optional): The configuration for bumpers. Bumpers are short audio or video clips that play at the start or before the end of an ad break. To learn more about bumpers, see Bumpers. Defaults to None.
        cdn_configuration(Dict, optional): The configuration for using a content delivery network (CDN), like Amazon CloudFront, for content and ad segment management. Defaults to None.
        configuration_aliases(Dict, optional): The player parameters and aliases used as dynamic variables during session initialization. For more information, see Domain Variables. . Defaults to None.
        dash_configuration(Dict, optional): The configuration for DASH content. Defaults to None.
        live_pre_roll_configuration(Dict, optional): The configuration for pre-roll ad insertion. Defaults to None.
        manifest_processing_rules(Dict, optional): The configuration for manifest processing rules. Manifest processing rules enable customization of the personalized manifests created by MediaTailor. Defaults to None.
        name(str, optional): The identifier for the playback configuration. Defaults to None.
        personalization_threshold_seconds(int, optional): Defines the maximum duration of underfilled ad time (in seconds) allowed in an ad break. If the duration of underfilled ad time exceeds the personalization threshold, then the personalization of the ad break is abandoned and the underlying content is shown. This feature applies to ad replacement in live and VOD streams, rather than ad insertion, because it relies on an underlying content stream. For more information about ad break behavior, including ad replacement and insertion, see Ad Behavior in AWS Elemental MediaTailor. Defaults to None.
        slate_ad_url(str, optional): The URL for a high-quality video asset to transcode and use to fill in time that's not used by ads. AWS Elemental MediaTailor shows the slate to fill in gaps in media content. Configuring the slate is optional for non-VPAID configurations. For VPAID, the slate is required because MediaTailor provides it in the slots that are designated for dynamic ad content. The slate must be a high-quality asset that contains both audio and video. Defaults to None.
        tags(Dict, optional): The tags to assign to the playback configuration. Defaults to None.
        transcode_profile_name(str, optional): The name that is used to associate this playback configuration with a custom transcode profile. This overrides the dynamic transcoding defaults of MediaTailor. Use this only if you have already set up custom profiles with the help of AWS Support. Defaults to None.
        video_content_source_url(str, optional): The URL prefix for the parent manifest for the stream, minus the asset ID. The maximum length is 512 characters. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediatailor.playback_configuration.put(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediatailor.playback_configuration.put
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediatailor",
        operation="put_playback_configuration",
        op_kwargs={
            "AdDecisionServerUrl": ad_decision_server_url,
            "AvailSuppression": avail_suppression,
            "Bumper": bumper,
            "CdnConfiguration": cdn_configuration,
            "ConfigurationAliases": configuration_aliases,
            "DashConfiguration": dash_configuration,
            "LivePreRollConfiguration": live_pre_roll_configuration,
            "ManifestProcessingRules": manifest_processing_rules,
            "Name": name,
            "PersonalizationThresholdSeconds": personalization_threshold_seconds,
            "SlateAdUrl": slate_ad_url,
            "Tags": tags,
            "TranscodeProfileName": transcode_profile_name,
            "VideoContentSourceUrl": video_content_source_url,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, domain: str, start_date: str, end_date: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieve inbox placement and engagement rates for the domains that you use to send email.

    Args:
        domain(str): The domain that you want to obtain deliverability metrics for.
        start_date(str): The first day (in Unix time) that you want to obtain domain deliverability metrics for.
        end_date(str): The last day (in Unix time) that you want to obtain domain deliverability metrics for. The EndDate that you specify has to be less than or equal to 30 days after the StartDate.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.pinpoint_email.domain.statistic_report.get(
                ctx, domain=value, start_date=value, end_date=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.pinpoint_email.domain.statistic_report.get domain=value, start_date=value, end_date=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="pinpoint-email",
        operation="get_domain_statistics_report",
        op_kwargs={"Domain": domain, "StartDate": start_date, "EndDate": end_date},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""


async def put(hub, ctx, channel_arn: str, metadata: str) -> None:
    r"""
    **Autogenerated function**

    Inserts metadata into the active stream of the specified channel. A maximum of 5 requests per second per channel is allowed, each with a maximum 1 KB payload. (If 5 TPS is not sufficient for your needs, we recommend batching your data into a single PutMetadata call.) Also see Embedding Metadata within a Video Stream in the Amazon IVS User Guide.

    Args:
        channel_arn(str): ARN of the channel into which metadata is inserted. This channel must have an active stream.
        metadata(str): Metadata to insert into the stream. Maximum: 1 KB per request.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ivs.metadata.put(ctx, channel_arn=value, metadata=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ivs.metadata.put channel_arn=value, metadata=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ivs",
        operation="put_metadata",
        op_kwargs={"channelArn": channel_arn, "metadata": metadata},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(
    hub,
    ctx,
    fleet_id: str,
    locations: List = None,
    limit: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information on a fleet's remote locations, including life-cycle status and any suspended fleet activity.  This operation can be used in the following ways:    To get data for specific locations, provide a fleet identifier and a list of locations. Location data is returned in the order that it is requested.    To get data for all locations, provide a fleet identifier only. Location data is returned in no particular order.    When requesting attributes for multiple locations, use the pagination parameters to retrieve results as a set of sequential pages.  If successful, a LocationAttributes object is returned for each requested location. If the fleet does not have a requested location, no information is returned. This operation does not return the home Region. To get information on a fleet's home Region, call DescribeFleetAttributes.  Learn more   Setting up GameLift fleets   Related actions   CreateFleetLocations | DescribeFleetLocationAttributes | DescribeFleetLocationCapacity | DescribeFleetLocationUtilization | DescribeFleetAttributes | DescribeFleetCapacity | DescribeFleetUtilization | UpdateFleetCapacity | StopFleetActions | DeleteFleetLocations | All APIs by task

    Args:
        fleet_id(str): A unique identifier for the fleet to retrieve remote locations for. You can use either the fleet ID or ARN value.
        locations(List, optional): A list of fleet locations to retrieve information for. Specify locations in the form of an AWS Region code, such as us-west-2. Defaults to None.
        limit(int, optional): The maximum number of results to return. Use this parameter with NextToken to get results as a set of sequential pages. This limit is not currently enforced. . Defaults to None.
        next_token(str, optional): A token that indicates the start of the next sequential page of results. Use the token that is returned with a previous call to this operation. To start at the beginning of the result set, do not specify a value. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.fleet.location.attribute.describe_all(
                ctx, fleet_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.fleet.location.attribute.describe_all fleet_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="describe_fleet_location_attributes",
        op_kwargs={
            "FleetId": fleet_id,
            "Locations": locations,
            "Limit": limit,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""


async def modify(
    hub,
    ctx,
    cluster_identifier: str,
    schedule_identifier: str = None,
    disassociate_schedule: bool = None,
) -> None:
    r"""
    **Autogenerated function**

    Modifies a snapshot schedule for a cluster.

    Args:
        cluster_identifier(str): A unique identifier for the cluster whose snapshot schedule you want to modify. .
        schedule_identifier(str, optional): A unique alphanumeric identifier for the schedule that you want to associate with the cluster. Defaults to None.
        disassociate_schedule(bool, optional): A boolean to indicate whether to remove the assoiciation between the cluster and the schedule. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.cluster.snapshot.schedule.modify(
                ctx, cluster_identifier=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.cluster.snapshot.schedule.modify cluster_identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="modify_cluster_snapshot_schedule",
        op_kwargs={
            "ClusterIdentifier": cluster_identifier,
            "ScheduleIdentifier": schedule_identifier,
            "DisassociateSchedule": disassociate_schedule,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def resolve(hub, ctx, platform: Dict, component_candidates: List) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a list of components that meet the component, version, and platform requirements of a deployment. Greengrass core devices call this operation when they receive a deployment to identify the components to install. This operation identifies components that meet all dependency requirements for a deployment. If the requirements conflict, then this operation returns an error and the deployment fails. For example, this occurs if component A requires version >2.0.0 and component B requires version <2.0.0 of a component dependency. When you specify the component candidates to resolve, IoT Greengrass compares each component's digest from the core device with the component's digest in the Amazon Web Services Cloud. If the digests don't match, then IoT Greengrass specifies to use the version from the Amazon Web Services Cloud.  To use this operation, you must use the data plane API endpoint and authenticate with an IoT device certificate. For more information, see IoT Greengrass endpoints and quotas.

    Args:
        platform(Dict): The platform to use to resolve compatible components.
        component_candidates(List): The list of components to resolve.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.greengrassv2.component.candidate.resolve(
                ctx, platform=value, component_candidates=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.greengrassv2.component.candidate.resolve platform=value, component_candidates=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="greengrassv2",
        operation="resolve_component_candidates",
        op_kwargs={"platform": platform, "componentCandidates": component_candidates},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    pool_name: str,
    policies: Dict = None,
    lambda_config: Dict = None,
    auto_verified_attributes: List = None,
    alias_attributes: List = None,
    username_attributes: List = None,
    sms_verification_message: str = None,
    email_verification_message: str = None,
    email_verification_subject: str = None,
    verification_message_template: Dict = None,
    sms_authentication_message: str = None,
    mfa_configuration: str = None,
    device_configuration: Dict = None,
    email_configuration: Dict = None,
    sms_configuration: Dict = None,
    user_pool_tags: Dict = None,
    admin_create_user_config: Dict = None,
    schema: List = None,
    user_pool_add_ons: Dict = None,
    username_configuration: Dict = None,
    account_recovery_setting: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new Amazon Cognito user pool and sets the password policy for the pool.  This action might generate an SMS text message. Starting June 1, 2021, U.S. telecom carriers require that you register an origination phone number before you can send SMS messages to U.S. phone numbers. If you use SMS text messages in Amazon Cognito, you must register a phone number with Amazon Pinpoint. Cognito will use the the registered number automatically. Otherwise, Cognito users that must receive SMS messages might be unable to sign up, activate their accounts, or sign in. If you have never used SMS text messages with Amazon Cognito or any other Amazon Web Service, Amazon SNS might place your account in SMS sandbox. In  sandbox mode , you’ll have limitations, such as sending messages to only verified phone numbers. After testing in the sandbox environment, you can move out of the SMS sandbox and into production. For more information, see  SMS message settings for Cognito User Pools in the Amazon Cognito Developer Guide.

    Args:
        pool_name(str): A string used to name the user pool.
        policies(Dict, optional): The policies associated with the new user pool. Defaults to None.
        lambda_config(Dict, optional): The Lambda trigger configuration information for the new user pool.  In a push model, event sources (such as Amazon S3 and custom applications) need permission to invoke a function. So you will need to make an extra call to add permission for these event sources to invoke your Lambda function.  For more information on using the Lambda API to add permission, see  AddPermission .  For adding permission using the CLI, see  add-permission . . Defaults to None.
        auto_verified_attributes(List, optional): The attributes to be auto-verified. Possible values: email, phone_number. Defaults to None.
        alias_attributes(List, optional): Attributes supported as an alias for this user pool. Possible values: phone_number, email, or preferred_username. Defaults to None.
        username_attributes(List, optional): Specifies whether email addresses or phone numbers can be specified as usernames when a user signs up. Defaults to None.
        sms_verification_message(str, optional): A string representing the SMS verification message. Defaults to None.
        email_verification_message(str, optional): A string representing the email verification message. EmailVerificationMessage is allowed only if EmailSendingAccount is DEVELOPER. . Defaults to None.
        email_verification_subject(str, optional): A string representing the email verification subject. EmailVerificationSubject is allowed only if EmailSendingAccount is DEVELOPER. . Defaults to None.
        verification_message_template(Dict, optional): The template for the verification message that the user sees when the app requests permission to access the user's information. Defaults to None.
        sms_authentication_message(str, optional): A string representing the SMS authentication message. Defaults to None.
        mfa_configuration(str, optional): Specifies MFA configuration details. Defaults to None.
        device_configuration(Dict, optional): The device configuration. Defaults to None.
        email_configuration(Dict, optional): The email configuration. Defaults to None.
        sms_configuration(Dict, optional): The SMS configuration. Defaults to None.
        user_pool_tags(Dict, optional): The tag keys and values to assign to the user pool. A tag is a label that you can use to categorize and manage user pools in different ways, such as by purpose, owner, environment, or other criteria. Defaults to None.
        admin_create_user_config(Dict, optional): The configuration for AdminCreateUser requests. Defaults to None.
        schema(List, optional): An array of schema attributes for the new user pool. These attributes can be standard or custom attributes. Defaults to None.
        user_pool_add_ons(Dict, optional): Used to enable advanced security risk detection. Set the key AdvancedSecurityMode to the value "AUDIT". Defaults to None.
        username_configuration(Dict, optional): You can choose to set case sensitivity on the username input for the selected sign-in option. For example, when this is set to False, users will be able to sign in using either "username" or "Username". This configuration is immutable once it has been set. For more information, see UsernameConfigurationType. Defaults to None.
        account_recovery_setting(Dict, optional): Use this setting to define which verified available method a user can use to recover their password when they call ForgotPassword. It allows you to define a preferred method when a user has more than one method available. With this setting, SMS does not qualify for a valid password recovery mechanism if the user also has SMS MFA enabled. In the absence of this setting, Cognito uses the legacy behavior to determine the recovery method where SMS is preferred over email. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_idp.user.pool.init.create(ctx, pool_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_idp.user.pool.init.create pool_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-idp",
        operation="create_user_pool",
        op_kwargs={
            "PoolName": pool_name,
            "Policies": policies,
            "LambdaConfig": lambda_config,
            "AutoVerifiedAttributes": auto_verified_attributes,
            "AliasAttributes": alias_attributes,
            "UsernameAttributes": username_attributes,
            "SmsVerificationMessage": sms_verification_message,
            "EmailVerificationMessage": email_verification_message,
            "EmailVerificationSubject": email_verification_subject,
            "VerificationMessageTemplate": verification_message_template,
            "SmsAuthenticationMessage": sms_authentication_message,
            "MfaConfiguration": mfa_configuration,
            "DeviceConfiguration": device_configuration,
            "EmailConfiguration": email_configuration,
            "SmsConfiguration": sms_configuration,
            "UserPoolTags": user_pool_tags,
            "AdminCreateUserConfig": admin_create_user_config,
            "Schema": schema,
            "UserPoolAddOns": user_pool_add_ons,
            "UsernameConfiguration": username_configuration,
            "AccountRecoverySetting": account_recovery_setting,
        },
    )


async def delete(hub, ctx, user_pool_id: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified Amazon Cognito user pool.

    Args:
        user_pool_id(str): The user pool ID for the user pool you want to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_idp.user.pool.init.delete(ctx, user_pool_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_idp.user.pool.init.delete user_pool_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-idp",
        operation="delete_user_pool",
        op_kwargs={"UserPoolId": user_pool_id},
    )


async def describe(hub, ctx, user_pool_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns the configuration information and metadata of the specified user pool.

    Args:
        user_pool_id(str): The user pool ID for the user pool you want to describe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_idp.user.pool.init.describe(ctx, user_pool_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_idp.user.pool.init.describe user_pool_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-idp",
        operation="describe_user_pool",
        op_kwargs={"UserPoolId": user_pool_id},
    )


async def list_all(hub, ctx, max_results: int, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists the user pools associated with an account.

    Args:
        next_token(str, optional): An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list. Defaults to None.
        max_results(int): The maximum number of results you want the request to return when listing the user pools.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_idp.user.pool.init.list_all(ctx, max_results=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_idp.user.pool.init.list_all max_results=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-idp",
        operation="list_user_pools",
        op_kwargs={"NextToken": next_token, "MaxResults": max_results},
    )


async def update(
    hub,
    ctx,
    user_pool_id: str,
    policies: Dict = None,
    lambda_config: Dict = None,
    auto_verified_attributes: List = None,
    sms_verification_message: str = None,
    email_verification_message: str = None,
    email_verification_subject: str = None,
    verification_message_template: Dict = None,
    sms_authentication_message: str = None,
    mfa_configuration: str = None,
    device_configuration: Dict = None,
    email_configuration: Dict = None,
    sms_configuration: Dict = None,
    user_pool_tags: Dict = None,
    admin_create_user_config: Dict = None,
    user_pool_add_ons: Dict = None,
    account_recovery_setting: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the specified user pool with the specified attributes. You can get a list of the current user pool settings using DescribeUserPool. If you don't provide a value for an attribute, it will be set to the default value.  This action might generate an SMS text message. Starting June 1, 2021, U.S. telecom carriers require that you register an origination phone number before you can send SMS messages to U.S. phone numbers. If you use SMS text messages in Amazon Cognito, you must register a phone number with Amazon Pinpoint. Cognito will use the the registered number automatically. Otherwise, Cognito users that must receive SMS messages might be unable to sign up, activate their accounts, or sign in. If you have never used SMS text messages with Amazon Cognito or any other Amazon Web Service, Amazon SNS might place your account in SMS sandbox. In  sandbox mode , you’ll have limitations, such as sending messages to only verified phone numbers. After testing in the sandbox environment, you can move out of the SMS sandbox and into production. For more information, see  SMS message settings for Cognito User Pools in the Amazon Cognito Developer Guide.

    Args:
        user_pool_id(str): The user pool ID for the user pool you want to update.
        policies(Dict, optional): A container with the policies you wish to update in a user pool. Defaults to None.
        lambda_config(Dict, optional): The Lambda configuration information from the request to update the user pool. Defaults to None.
        auto_verified_attributes(List, optional): The attributes that are automatically verified when the Amazon Cognito service makes a request to update user pools. Defaults to None.
        sms_verification_message(str, optional): A container with information about the SMS verification message. Defaults to None.
        email_verification_message(str, optional): The contents of the email verification message. Defaults to None.
        email_verification_subject(str, optional): The subject of the email verification message. Defaults to None.
        verification_message_template(Dict, optional): The template for verification messages. Defaults to None.
        sms_authentication_message(str, optional): The contents of the SMS authentication message. Defaults to None.
        mfa_configuration(str, optional): Can be one of the following values:    OFF - MFA tokens are not required and cannot be specified during user registration.    ON - MFA tokens are required for all user registrations. You can only specify ON when you are initially creating a user pool. You can use the SetUserPoolMfaConfig API operation to turn MFA "ON" for existing user pools.     OPTIONAL - Users have the option when registering to create an MFA token.  . Defaults to None.
        device_configuration(Dict, optional): Device configuration. Defaults to None.
        email_configuration(Dict, optional): Email configuration. Defaults to None.
        sms_configuration(Dict, optional): SMS configuration. Defaults to None.
        user_pool_tags(Dict, optional): The tag keys and values to assign to the user pool. A tag is a label that you can use to categorize and manage user pools in different ways, such as by purpose, owner, environment, or other criteria. Defaults to None.
        admin_create_user_config(Dict, optional): The configuration for AdminCreateUser requests. Defaults to None.
        user_pool_add_ons(Dict, optional): Used to enable advanced security risk detection. Set the key AdvancedSecurityMode to the value "AUDIT". Defaults to None.
        account_recovery_setting(Dict, optional): Use this setting to define which verified available method a user can use to recover their password when they call ForgotPassword. It allows you to define a preferred method when a user has more than one method available. With this setting, SMS does not qualify for a valid password recovery mechanism if the user also has SMS MFA enabled. In the absence of this setting, Cognito uses the legacy behavior to determine the recovery method where SMS is preferred over email. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_idp.user.pool.init.update(ctx, user_pool_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_idp.user.pool.init.update user_pool_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-idp",
        operation="update_user_pool",
        op_kwargs={
            "UserPoolId": user_pool_id,
            "Policies": policies,
            "LambdaConfig": lambda_config,
            "AutoVerifiedAttributes": auto_verified_attributes,
            "SmsVerificationMessage": sms_verification_message,
            "EmailVerificationMessage": email_verification_message,
            "EmailVerificationSubject": email_verification_subject,
            "VerificationMessageTemplate": verification_message_template,
            "SmsAuthenticationMessage": sms_authentication_message,
            "MfaConfiguration": mfa_configuration,
            "DeviceConfiguration": device_configuration,
            "EmailConfiguration": email_configuration,
            "SmsConfiguration": sms_configuration,
            "UserPoolTags": user_pool_tags,
            "AdminCreateUserConfig": admin_create_user_config,
            "UserPoolAddOns": user_pool_add_ons,
            "AccountRecoverySetting": account_recovery_setting,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""


async def add(
    hub, ctx, db_cluster_identifier: str, role_arn: str, feature_name: str = None
) -> None:
    r"""
    **Autogenerated function**

    Associates an Identity and Access Management (IAM) role from an Amazon Aurora DB cluster. For more information, see Authorizing Amazon Aurora MySQL to Access Other Amazon Web Services Services on Your Behalf in the Amazon Aurora User Guide.  This action only applies to Aurora DB clusters.

    Args:
        db_cluster_identifier(str): The name of the DB cluster to associate the IAM role with.
        role_arn(str): The Amazon Resource Name (ARN) of the IAM role to associate with the Aurora DB cluster, for example, arn:aws:iam::123456789012:role/AuroraAccessRole.
        feature_name(str, optional): The name of the feature for the DB cluster that the IAM role is to be associated with. For the list of supported feature names, see DBEngineVersion. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.role.to_db.cluster.add(
                ctx, db_cluster_identifier=value, role_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.role.to_db.cluster.add db_cluster_identifier=value, role_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="add_role_to_db_cluster",
        op_kwargs={
            "DBClusterIdentifier": db_cluster_identifier,
            "RoleArn": role_arn,
            "FeatureName": feature_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__virtualname__ = "from_permission_set"


async def detach(
    hub, ctx, instance_arn: str, permission_set_arn: str, managed_policy_arn: str
) -> Dict:
    r"""
    **Autogenerated function**

    Detaches the attached IAM managed policy ARN from the specified permission set.

    Args:
        instance_arn(str): The ARN of the SSO instance under which the operation will be executed. For more information about ARNs, see Amazon Resource Names (ARNs) and Amazon Web Services Service Namespaces in the Amazon Web Services General Reference.
        permission_set_arn(str): The ARN of the PermissionSet from which the policy should be detached.
        managed_policy_arn(str): The IAM managed policy ARN to be attached to a permission set.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sso_admin.managed_policy.from_permission_set_.detach(
                ctx, instance_arn=value, permission_set_arn=value, managed_policy_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sso_admin.managed_policy.from_permission_set.detach instance_arn=value, permission_set_arn=value, managed_policy_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sso-admin",
        operation="detach_managed_policy_from_permission_set",
        op_kwargs={
            "InstanceArn": instance_arn,
            "PermissionSetArn": permission_set_arn,
            "ManagedPolicyArn": managed_policy_arn,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx, arn: str, revision: int) -> Dict:
    r"""
        **Autogenerated function**


        Returns a description of this revision of the configuration.


        Args:
            arn(str):
    The Amazon Resource Name (ARN) that uniquely identifies an MSK configuration and all of its revisions.
    .
            revision(int):
    A string that uniquely identifies a revision of an MSK configuration.
    .

        Returns:
            Dict

        Examples:
            Call from code:

            .. code-block:: python

                await hub.exec.aws_auto.kafka.configuration.revision.describe(
                    ctx, arn=value, revision=value
                )

            Call from CLI:

            .. code-block:: bash

                $ idem exec aws_auto.kafka.configuration.revision.describe arn=value, revision=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kafka",
        operation="describe_configuration_revision",
        op_kwargs={"Arn": arn, "Revision": revision},
    )


async def list_all(
    hub, ctx, arn: str, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
        **Autogenerated function**


        Returns a list of all the MSK configurations in this Region.


        Args:
            arn(str):
    The Amazon Resource Name (ARN) that uniquely identifies an MSK configuration and all of its revisions.
    .
            max_results(int, optional):
    The maximum number of results to return in the response. If there are more results, the response includes a NextToken parameter.
    . Defaults to None.
            next_token(str, optional):
    The paginated results marker. When the result of the operation is truncated, the call returns NextToken in the response.
                To get the next batch, provide this token in your next request.
    . Defaults to None.

        Returns:
            Dict

        Examples:
            Call from code:

            .. code-block:: python

                await hub.exec.aws_auto.kafka.configuration.revision.list_all(ctx, arn=value)

            Call from CLI:

            .. code-block:: bash

                $ idem exec aws_auto.kafka.configuration.revision.list_all arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kafka",
        operation="list_configuration_revisions",
        op_kwargs={"Arn": arn, "MaxResults": max_results, "NextToken": next_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def update(
    hub, ctx, container_instances: List, status: str, cluster: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Modifies the status of an Amazon ECS container instance. Once a container instance has reached an ACTIVE state, you can change the status of a container instance to DRAINING to manually remove an instance from a cluster, for example to perform system updates, update the Docker daemon, or scale down the cluster size.  A container instance cannot be changed to DRAINING until it has reached an ACTIVE status. If the instance is in any other status, an error will be received.  When you set a container instance to DRAINING, Amazon ECS prevents new tasks from being scheduled for placement on the container instance and replacement service tasks are started on other container instances in the cluster if the resources are available. Service tasks on the container instance that are in the PENDING state are stopped immediately. Service tasks on the container instance that are in the RUNNING state are stopped and replaced according to the service's deployment configuration parameters, minimumHealthyPercent and maximumPercent. You can change the deployment configuration of your service using UpdateService.   If minimumHealthyPercent is below 100%, the scheduler can ignore desiredCount temporarily during task replacement. For example, desiredCount is four tasks, a minimum of 50% allows the scheduler to stop two existing tasks before starting two new tasks. If the minimum is 100%, the service scheduler can't remove existing tasks until the replacement tasks are considered healthy. Tasks for services that do not use a load balancer are considered healthy if they are in the RUNNING state. Tasks for services that use a load balancer are considered healthy if they are in the RUNNING state and the container instance they are hosted on is reported as healthy by the load balancer.   The maximumPercent parameter represents an upper limit on the number of running tasks during task replacement, which enables you to define the replacement batch size. For example, if desiredCount is four tasks, a maximum of 200% starts four new tasks before stopping the four tasks to be drained, provided that the cluster resources required to do this are available. If the maximum is 100%, then replacement tasks can't start until the draining tasks have stopped.   Any PENDING or RUNNING tasks that do not belong to a service are not affected. You must wait for them to finish or stop them manually. A container instance has completed draining when it has no more RUNNING tasks. You can verify this using ListTasks. When a container instance has been drained, you can set a container instance to ACTIVE status and once it has reached that status the Amazon ECS scheduler can begin scheduling tasks on the instance again.

    Args:
        cluster(str, optional): The short name or full Amazon Resource Name (ARN) of the cluster that hosts the container instance to update. If you do not specify a cluster, the default cluster is assumed. Defaults to None.
        container_instances(List): A list of container instance IDs or full ARN entries.
        status(str): The container instance state with which to update the container instance. The only valid values for this action are ACTIVE and DRAINING. A container instance can only be updated to DRAINING status once it has reached an ACTIVE state. If a container instance is in REGISTERING, DEREGISTERING, or REGISTRATION_FAILED state you can describe the container instance but will be unable to update the container instance state.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecs.container.instance.state.update(
                ctx, container_instances=value, status=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecs.container.instance.state.update container_instances=value, status=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecs",
        operation="update_container_instances_state",
        op_kwargs={
            "cluster": cluster,
            "containerInstances": container_instances,
            "status": status,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe(hub, ctx, fleet_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes the networking configuration to access the internal websites associated with the specified fleet.

    Args:
        fleet_arn(str): The ARN of the fleet.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.worklink.company_network_configuration.describe(
                ctx, fleet_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.worklink.company_network_configuration.describe fleet_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="worklink",
        operation="describe_company_network_configuration",
        op_kwargs={"FleetArn": fleet_arn},
    )


async def update(
    hub, ctx, fleet_arn: str, vpc_id: str, subnet_ids: List, security_group_ids: List
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the company network configuration for the fleet.

    Args:
        fleet_arn(str): The ARN of the fleet.
        vpc_id(str): The VPC with connectivity to associated websites.
        subnet_ids(List): The subnets used for X-ENI connections from Amazon WorkLink rendering containers.
        security_group_ids(List): The security groups associated with access to the provided subnets.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.worklink.company_network_configuration.update(
                ctx, fleet_arn=value, vpc_id=value, subnet_ids=value, security_group_ids=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.worklink.company_network_configuration.update fleet_arn=value, vpc_id=value, subnet_ids=value, security_group_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="worklink",
        operation="update_company_network_configuration",
        op_kwargs={
            "FleetArn": fleet_arn,
            "VpcId": vpc_id,
            "SubnetIds": subnet_ids,
            "SecurityGroupIds": security_group_ids,
        },
    )
